"""
Chessboard Generator for Camera Calibration
A simple tool to generate chessboard patterns for OpenCV camera calibration
"""

__version__ = "1.0.1"
__author__ = "batuhan ÖKMEN"
__email__ = "batuhanokmen@gmail.com"

from .generator import ChessboardGenerator

__all__ = ['ChessboardGenerator']
